Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/config
diff options
context:
space:
mode:
authorMatthieu Napoli <matthieu@mnapoli.fr>2014-12-10 01:45:43 +0300
committerMatthieu Napoli <matthieu@mnapoli.fr>2014-12-10 01:45:43 +0300
commit3fd7de50f46c099cd5d7821f7a54c485d79ee5a9 (patch)
treef42e34fd0d6becb69c27c3ffb69524d2a2d1bab0 /config
parentaad92e94052b7fe0cc617ec52e09c8a295c9ed4b (diff)
#6622 Logger refactoring: renamed "Backend" to "Handler" to match Monolog naming
Diffstat (limited to 'config')
-rw-r--r--config/global.php18
1 files changed, 9 insertions, 9 deletions
diff --git a/config/global.php b/config/global.php
index 3695ecf8dc..6e31cb8aa5 100644
--- a/config/global.php
+++ b/config/global.php
@@ -4,7 +4,7 @@ use Interop\Container\ContainerInterface;
use Monolog\Logger;
use Piwik\Common;
use Piwik\Log;
-use Piwik\Log\Backend\StdErrBackend;
+use Piwik\Log\Handler\StdErrHandler;
return array(
@@ -38,9 +38,9 @@ return array(
}
$classes = array(
- 'file' => 'Piwik\Log\Backend\FileBackend',
- 'screen' => 'Piwik\Log\Backend\StdOutBackend',
- 'database' => 'Piwik\Log\Backend\DatabaseBackend',
+ 'file' => 'Piwik\Log\Handler\FileHandler',
+ 'screen' => 'Piwik\Log\Handler\StdOutHandler',
+ 'database' => 'Piwik\Log\Handler\DatabaseHandler',
);
$writerNames = array_map('trim', $writerNames);
@@ -52,9 +52,9 @@ return array(
}
}
// Always add the stderr backend
$isLoggingToStdOut = isset($writers['screen']);
- $writers['stderr'] = new StdErrBackend($c->get('Piwik\Log\Formatter\ExceptionHtmlFormatter'), $isLoggingToStdOut);
+ $writers['stderr'] = new StdErrHandler($c->get('Piwik\Log\Formatter\ExceptionHtmlFormatter'), $isLoggingToStdOut);
return array_values($writers);
}),
@@ -64,13 +64,13 @@ return array(
DI\link('Piwik\Log\Processor\SprintfProcessor'),
DI\link('Monolog\Processor\PsrLogMessageProcessor'),
),
- 'Piwik\Log\Backend\FileBackend' => DI\object()
+ 'Piwik\Log\Handler\FileHandler' => DI\object()
->constructor(DI\link('log.file.filename'), DI\link('log.level'))
->method('setFormatter', DI\link('Piwik\Log\Formatter\ExceptionTextFormatter')),
- 'Piwik\Log\Backend\DatabaseBackend' => DI\object()
+ 'Piwik\Log\Handler\DatabaseHandler' => DI\object()
->constructor(DI\link('log.level'))
->method('setFormatter', DI\link('Piwik\Log\Formatter\ExceptionTextFormatter')),
- 'Piwik\Log\Backend\StdOutBackend' => DI\object()
+ 'Piwik\Log\Handler\StdOutHandler' => DI\object()
->constructor(DI\link('log.level'))
->method('setFormatter', DI\link('Piwik\Log\Formatter\ExceptionHtmlFormatter')),
'log.level' => DI\factory(function (ContainerInterface $c) {
@@ -52,9 +52,9 @@ return array(
}
}
- // Always add the stderr backend
+ // Always add the stderr handler
$isLoggingToStdOut = isset($writers['screen']);